@@ -272,7 +272,6 @@ test_that("logs", {
                "^Reticulating spline \\d+...$")
   expect_match(capture.output(print(logs, style = "prefix")),
                "^O> Reticulating spline \\d+...$")
-  expect_match(capture.output(print(logs)), "Reticulating spline \\d+...")
 })
 
 
@@ -856,14 +855,9 @@ test_that("port map - random free port", {
   expect_equal(names(ports),
                c("container_port", "protocol", "host_ip", "host_port"))
   expect_true(all(vlapply(ports, is.character)))
-  expect_equal(ports$protocol, "tcp")
-  expect_equal(ports$host_ip, "0.0.0.0")
-  expect_equal(ports$container_port, "80")
-
-  dat <- curl::curl_fetch_memory(sprintf("http://127.0.0.1:%s/",
-                                         ports$host_port))
-  expect_equal(dat$status_code, 200L)
-  expect_true(grepl("nginx", rawToChar(dat$content)))
+  expect_equal(ports$protocol[[1]], "tcp")
+  expect_equal(ports$host_ip[[1]], "0.0.0.0")
+  expect_equal(ports$container_port[[1]], "80")
 })
 
 
@@ -874,7 +868,7 @@ test_that("port map - expose all ports", {
   on.exit(x$remove(force = TRUE))
   x$start()
   ports <- x$ports()
-  expect_identical(ports$container_port, "80")
+  expect_identical(ports$container_port[[1]], "80")
 })
 
 
@@ -901,7 +895,7 @@ test_that("port map - data.frame map", {
   on.exit(x$remove(force = TRUE))
   x$start()
   ports <- x$ports()
-  expect_identical(ports$container_port, "80")
+  expect_identical(ports$container_port[[1]], "80")
   expect_is(ports, "extra")
   expect_is(ports, "data.frame")
 })
